** 	SPSS program to create Revised unmet need variable as described in
	Analytical Study 25: Revising Unmet Need for Family Planing
	by Bradley, Croft, Fishel, and Westoff, 2012, published by ICF International
	measuredhs.com/pubs/pdf/AS25/AS25.pdf
** 	Program written by Trevor Croft and edited by Sarah Bradley, last updated 26 January 2011
	TCroft@icfi.com
** 	This program will work for most surveys. If your results do not match
	Revising Unmet Need for Family Planning, the survey you are analyzing may require
	survey-specific programming. See survey-specific link at measuredhs.com/topics/Unmet-Need.cfm.
**  Correction 12 March 2014 for the selection of currently married women in the frequencies at the end.  Now uses v502=1, not v501=1 - Trevor Croft.
**	Note that some statements will generate an error message if the variable mentioned does not exist in a particular survey - this should not cause a problem.
**  Correction 10 May 2017 to work with DHS7 datasets
    Two changes: checks for v000 now look for "7", and tsinceb now calculated using v222 which is based on century day codes in DHS7.
**  Correction 17 March 2021 Trevor Croft: to work with DHS8 datasets, and to conform to standard coding of v626a.

**Set unmet need to NA for unmarried women if survey only included ever-married women .
if (v502<>1 & v020=1) unmet=98.

** CONTRACEPTIVE USERS - GROUP 1.
do if (sysmis(unmet) & v312<>0).
* using to space - all contraceptive users, except those below.
+ compute unmet=3.
* using to limit if wants no more, sterilized, or declared infecund.
+ if (v605>=5 & v605<=7) unmet=4.
end if.

**PREGNANT or POSTPARTUM AMENORRHEIC (PPA) WOMEN - GROUP 2.
* Determine who should be in Group 2.
* generate time since last birth.
compute tsinceb=v222.

* generate time since last period in months from v215.
if (v215>=100 & v215<=190) tsincep=trunc((v215-100)/30).
if (v215>=200 & v215<=290) tsincep=trunc((v215-200)/4.3).
if (v215>=300 & v215<=390) tsincep=(v215-300).
if (v215>=400 & v215<=490) tsincep=(v215-400)*12.
* initialize pregnant or postpartum amenorrheic (PPA) women.
compute pregPPA=0.
if (v213=1 | m6$1=96) pregPPA=1.
* For women with missing data or "period not returned" on date of last menstrual period, use information from time since last period.
do if (sysmis(m6$1) | m6$1=99 | m6$1=97).
*   if last period is before last birth in last 5 years.
+ if (not sysmis(tsinceb) & not sysmis(tsincep) & tsincep>tsinceb & tsinceb<60) pregPPA=1.
*   if said "before last birth" to time since last period in the last 5 years.
+ if (not sysmis(tsinceb) & v215=995 & tsinceb<60) pregPPA=1.
end if.

* select only women who are pregnant or PPA for <24 months.
compute pregPPA24=0.
if (v213=1 | (pregPPA=1 & not sysmis(tsinceb) & tsinceb<24)) pregPPA24=1.

* Classify wantedness of current pregnancy/last birth.
* current pregnancy.
compute wantedlast=v225.
* last birth.
if ((sysmis(wantedlast) | wantedlast=9) & v213<>1) wantedlast = m10$1.

variable labels wantedlast "Wantedness of current pregnancy or last birth".
value labels wantedlast 1 "Then" 2 "Later" 3 "Not at all".
formats wantedlast (f1.0).

* Unmet need status of pregnant women or women PPA for <24 months.
do if (sysmis(unmet) & pregPPA24=1).
* no unmet need if wanted current pregnancy/last birth then/at that time.
+ if (wantedlast=1) unmet=7.
* unmet need for spacing if wanted current pregnancy/last birth later.
+ if (wantedlast=2) unmet=1.
* unmet need for limiting if wanted current pregnancy/last birth not at all.
+ if (wantedlast=3) unmet=2.
* missing=missing.
+ if (sysmis(wantedlast) | wantedlast=9) unmet=99.
end if.


**DETERMINE FECUNDITY - GROUP 3.
compute infec=0.
**Boxes 1-4 only apply to women who are not pregnant and not PPA<24 months.
do if (sysmis(unmet) & v213<>1 & pregPPA24<>1).
+ compute infec=0.

**Box 1 - applicable only to currently married.
* married 5+ years ago, no children in past 5 years, never used contraception, excluding pregnant and PPA <24 months.
+ if (v502=1 & not sysmis(v512) & v512>=5 & (sysmis(tsinceb) | tsinceb>59) & v302=0 & pregPPA24<>1) infec=1 .
* in DHS VI, v302 replaced by v302a.
+ if (v502=1 & not sysmis(v512) & v512>=5 & (sysmis(tsinceb) | tsinceb>59) & v302a=0 & pregPPA24<>1 & (substr(v000,3,1)="6" | substr(v000,3,1)="7")) infec=1 .

**Box 2.
* declared infecund on future desires for children.
+ if (v605=7) infec=2.

**Box 3.
* menopausal/hysterectomy on reason not using contraception - slightly different recoding in DHS III and IV+.
* DHS IV+ surveys.
+ if (v3a08d=1 & (substr(v000,3,1)="4" | substr(v000,3,1)="5" | substr(v000,3,1)="6" | substr(v000,3,1)="7" | substr(v000,3,1)="8")) infec=3.
* DHSIII surveys.
+ if (v375a=23 & (substr(v000,3,1)="3" | substr(v000,3,1)="T")) infec=3.
* Reason not using did not exist in DHSII, use reason not intending to use in future.
+ if (v376=14 & substr(v000,3,1)="2") infec=3.

**Box 4.
* Time since last period is >=6 months and not PPA.
+ if (not sysmis(tsincep) & tsincep>=6 & pregPPA<>1) infec=4.

**Box 5.
* menopause/hysterectomy on time since last period.
+ if (v215=994) infec=5.
* never menstruated on time since last period, unless had a birth in the last 5 years.
+ if (v215=996 & (sysmis(tsinceb) | tsinceb>59)) infec=5.

**Box 6.
* time since last birth>= 60 months and last period was before last birth.
+ if (v215=995 & not sysmis(tsinceb) & tsinceb>59) infec=6.
* never had a birth, but last period reported as before last birth - assume code should have been 994 or 996.
+ if (v215=995 & sysmis(tsinceb)) infec=6.

**INFECUND - GROUP 3.
+ if (infec>0 & sysmis(unmet)) unmet=9.

** End of code for women who are not pregnant and not PPA<24 months.
end if.

**NO NEED FOR UNMARRIED WOMEN WHO ARE NOT SEXUALLY ACTIVE.
* determine if sexually active in last 30 days.
compute sexact=0.
if (v528>=0 & v528<=30) sexact=1.
variable labels sexact "Sexually active in last 30 days".
value labels sexact 1 "Yes" 2 "No".
formats sexact (f1.0).

* if unmarried and never had sex, assume no need.
if (sysmis(unmet) & v502<>1 & v525=0) unmet=0. 
* if unmarried and not sexually active in last 30 days, assume no need.
if (sysmis(unmet) & v502<>1 & sexact<>1) unmet=8. 

**FECUND WOMEN - GROUP 4.
do if sysmis(unmet).
* wants within 2 years.
+ if (v605=1) unmet=7.
* wants in 2+ years, wants undecided timing, or unsure if wants.
+ if (v605>=2 & v605<=4) unmet=1.
* wants no more.
+ if (v605=5) unmet=2.
end if.

recode unmet (sysmis=99).

value labels unmet
  0 "never had sex"
  1 "unmet need for spacing"
  2 "unmet need for limiting"
  3 "using for spacing"
  4 "using for limiting"
  7 "no unmet need"
  8 "not sexually active"
  9 "infecund or menopausal"
 98 "unmarried - EM sample or no data"
 99 "missing"
.

recode unmet (1,2=1) (else=0) into unmettot.
variable labels unmettot "Unmet need for family planning".
value labels unmettot 1 "unmet need" 0  "no unmet need".
formats unmet unmettot (f1.0).

**TABULATE RESULTS.
* generate sampling weight.
compute wgt=v005/1000000.
weight by wgt.

**married.
use all.
compute filter_$=(v502=1).
filter by filter_$.
frequencies unmet, unmettot.

**all women.
use all.
frequencies unmet, unmettot.

**sexually active unmarried.
use all.
compute filter_$=(v502<>1 & sexact=1).
filter by filter_$.
frequencies unmet, unmettot.

